artellapipe-tools-bugtracker
============================================================

Tool to handle bugs and requests for the different tools of the pipeline

.. image:: https://travis-ci.com/ArtellaPipe/artellapipe-tools-bugtracker.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/ArtellaPipe/artellapipe-tools-bugtracker

.. image:: https://coveralls.io/repos/github/ArtellaPipe/artellapipe-tools-bugtracker/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/ArtellaPipe/artellapipe-tools-bugtracker?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://artellapipe.github.io/artellapipe-tools-bugtracker/

.. image:: https://img.shields.io/github/license/ArtellaPipe/artellapipe-tools-bugtracker
    :target: https://github.com/ArtellaPipe/artellapipe-tools-bugtracker/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/artellapipe-tools-bugtracker?branch=master&kill_cache=1
    :target: https://pypi.org/project/artellapipe-tools-bugtracker/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/